@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2021, Intel Corporation */
 
 /*
  * memblock.c -- implementation of memory block
@@ -52,6 +23,7 @@
 #include "memblock.h"
 #include "out.h"
 #include "valgrind_internal.h"
+#include "alloc_class.h"
 
 /* calculates the size of the entire run, including any additional chunks */
 #define SIZEOF_RUN(runp, size_idx)\
@@ -497,13 +469,19 @@ memblock_run_bitmap(uint32_t *size_idx, uint16_t flags,
 static void
 run_get_bitmap(const struct memory_block *m, struct run_bitmap *b)
 {
-	struct chunk_header *hdr = heap_get_chunk_hdr(m->heap, m);
 	struct chunk_run *run = heap_get_chunk_run(m->heap, m);
 
-	uint32_t size_idx = hdr->size_idx;
-	memblock_run_bitmap(&size_idx, hdr->flags, run->hdr.block_size,
-		run->hdr.alignment, run->content, b);
-	ASSERTeq(size_idx, hdr->size_idx);
+	if (m->cached_bitmap != NULL) {
+		*b = *m->cached_bitmap;
+		b->values = (uint64_t *)run->content;
+	} else {
+		struct chunk_header *hdr = heap_get_chunk_hdr(m->heap, m);
+
+		uint32_t size_idx = hdr->size_idx;
+		memblock_run_bitmap(&size_idx, hdr->flags, run->hdr.block_size,
+			run->hdr.alignment, run->content, b);
+		ASSERTeq(size_idx, hdr->size_idx);
+	}
 }
 
 /*
@@ -806,7 +784,10 @@ huge_ensure_header_type(const struct memory_block *m,
 	if ((hdr->flags & header_type_to_flag[t]) == 0) {
 		VALGRIND_ADD_TO_TX(hdr, sizeof(*hdr));
 		uint16_t f = ((uint16_t)header_type_to_flag[t]);
-		hdr->flags |= f;
+		uint64_t nhdr = chunk_get_chunk_hdr_value(hdr->type,
+			hdr->flags | f, hdr->size_idx);
+		util_atomic_store_explicit64((uint64_t *)hdr,
+			nhdr, memory_order_relaxed);
 		pmemops_persist(&m->heap->p_ops, hdr, sizeof(*hdr));
 		VALGRIND_REMOVE_FROM_TX(hdr, sizeof(*hdr));
 	}
@@ -1321,18 +1302,15 @@ memblock_huge_init(struct palloc_heap *heap,
 	m.size_idx = size_idx;
 	m.heap = heap;
 
-	struct chunk_header nhdr = {
-		.type = CHUNK_TYPE_FREE,
-		.flags = 0,
-		.size_idx = size_idx
-	};
-
 	struct chunk_header *hdr = heap_get_chunk_hdr(heap, &m);
 
 	VALGRIND_DO_MAKE_MEM_UNDEFINED(hdr, sizeof(*hdr));
 	VALGRIND_ANNOTATE_NEW_MEMORY(hdr, sizeof(*hdr));
 
-	*hdr = nhdr; /* write the entire header (8 bytes) at once */
+	uint64_t nhdr = chunk_get_chunk_hdr_value(CHUNK_TYPE_FREE,
+		0, size_idx);
+	util_atomic_store_explicit64((uint64_t *)hdr,
+		nhdr, memory_order_relaxed);
 
 	pmemops_persist(&heap->p_ops, hdr, sizeof(*hdr));
 
@@ -1348,9 +1326,9 @@ memblock_huge_init(struct palloc_heap *heap,
  */
 struct memory_block
 memblock_run_init(struct palloc_heap *heap,
-	uint32_t chunk_id, uint32_t zone_id, uint32_t size_idx, uint16_t flags,
-	uint64_t unit_size, uint64_t alignment)
+	uint32_t chunk_id, uint32_t zone_id, struct run_descriptor *rdsc)
 {
+	uint32_t size_idx = rdsc->size_idx;
 	ASSERTne(size_idx, 0);
 
 	struct memory_block m = MEMORY_BLOCK_NONE;
@@ -1368,12 +1346,11 @@ memblock_run_init(struct palloc_heap *heap,
 
 	/* add/remove chunk_run and chunk_header to valgrind transaction */
 	VALGRIND_ADD_TO_TX(run, runsize);
-	run->hdr.block_size = unit_size;
-	run->hdr.alignment = alignment;
+	run->hdr.block_size = rdsc->unit_size;
+	run->hdr.alignment = rdsc->alignment;
 
-	struct run_bitmap b;
-	memblock_run_bitmap(&size_idx, flags, unit_size, alignment,
-		run->content, &b);
+	struct run_bitmap b = rdsc->bitmap;
+	b.values = (uint64_t *)run->content;
 
 	size_t bitmap_size = b.size;
 
@@ -1417,17 +1394,17 @@ memblock_run_init(struct palloc_heap *heap,
 
 	VALGRIND_ANNOTATE_NEW_MEMORY(hdr, sizeof(*hdr));
 
-	struct chunk_header run_hdr;
-	run_hdr.size_idx = hdr->size_idx;
-	run_hdr.type = CHUNK_TYPE_RUN;
-	run_hdr.flags = flags;
-	*hdr = run_hdr;
+	uint64_t run_hdr = chunk_get_chunk_hdr_value(CHUNK_TYPE_RUN,
+		rdsc->flags, hdr->size_idx);
+	util_atomic_store_explicit64((uint64_t *)hdr,
+		run_hdr, memory_order_relaxed);
 	pmemops_persist(&heap->p_ops, hdr, sizeof(*hdr));
 
 	VALGRIND_REMOVE_FROM_TX(&z->chunk_headers[chunk_id],
 		sizeof(struct chunk_header) * size_idx);
 
 	memblock_rebuild_state(heap, &m);
+	m.cached_bitmap = &rdsc->bitmap;
 
 	return m;
 }
@@ -1499,6 +1476,14 @@ memblock_from_offset_opt(struct palloc_heap *heap, uint64_t off, int size)
 		off -= m.block_off * unit_size;
 	}
 
+	struct alloc_class_collection *acc = heap_alloc_classes(heap);
+	if (acc != NULL) {
+		struct alloc_class *ac = alloc_class_by_run(acc,
+			unit_size, hdr->flags, hdr->size_idx);
+		if (ac != NULL)
+			m.cached_bitmap = &ac->rdsc.bitmap;
+	}
+
 	m.size_idx = !size ? 0 : CALC_SIZE_IDX(unit_size,
 		memblock_header_ops[m.header_type].get_size(&m));
 
@@ -1530,4 +1515,5 @@ memblock_rebuild_state(struct palloc_heap *heap, struct memory_block *m)
 	m->header_type = memblock_header_type(m);
 	m->type = memblock_detect_type(heap, m);
 	m->m_ops = &mb_ops[m->type];
+	m->cached_bitmap = NULL;
 }
