@@ -1,34 +1,5 @@
-/*
- * Copyright 2015-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2015-2021, Intel Corporation */
 
 /*
  * pmalloc.c -- implementation of pmalloc POSIX-like API
@@ -39,6 +10,8 @@
  */
 
 #include <inttypes.h>
+#include "ctl.h"
+#include "libpmemobj/ctl.h"
 #include "valgrind_internal.h"
 #include "heap.h"
 #include "lane.h"
@@ -213,7 +186,7 @@ pmalloc_boot(PMEMobjpool *pop)
 		return ret;
 
 #if VG_MEMCHECK_ENABLED
-	if (On_valgrind)
+	if (On_memcheck)
 		palloc_heap_vg_open(&pop->heap, pop->vg_boot);
 #endif
 
@@ -334,7 +307,7 @@ CTL_WRITE_HANDLER(desc)(void *ctx,
 	}
 
 	p->class_id = c->id;
-	p->units_per_block = c->run.nallocs;
+	p->units_per_block = c->rdsc.nallocs;
 
 	return 0;
 }
@@ -411,11 +384,11 @@ CTL_READ_HANDLER(desc)(void *ctx,
 	}
 
 	struct pobj_alloc_class_desc *p = arg;
-	p->units_per_block = c->type == CLASS_HUGE ? 0 : c->run.nallocs;
+	p->units_per_block = c->type == CLASS_HUGE ? 0 : c->rdsc.nallocs;
 	p->header_type = user_htype;
 	p->unit_size = c->unit_size;
 	p->class_id = c->id;
-	p->alignment = c->flags & CHUNK_FLAG_ALIGNED ? c->run.alignment : 0;
+	p->alignment = c->flags & CHUNK_FLAG_ALIGNED ? c->rdsc.alignment : 0;
 
 	return 0;
 }
@@ -824,3 +797,81 @@ pmalloc_ctl_register(PMEMobjpool *pop)
 {
 	CTL_REGISTER_MODULE(pop->ctl, heap);
 }
+
+/*
+ * CTL_WRITE_HANDLER(arenas_assignment_type) -- sets the current arenas
+ *	assignment type
+ */
+static int
+CTL_WRITE_HANDLER(arenas_assignment_type)(void *ctx,
+	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
+{
+	enum pobj_arenas_assignment_type *src = arg;
+
+	Default_arenas_assignment_type = *src;
+
+	return 0;
+}
+
+/*
+ * CTL_READ_HANDLER(arenas_assignment_type) --
+ *	reads the current arena assignment type
+ */
+static int
+CTL_READ_HANDLER(arenas_assignment_type)(void *ctx,
+	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
+{
+	enum pobj_arenas_assignment_type *dest = arg;
+
+	*dest = Default_arenas_assignment_type;
+
+	return 0;
+}
+
+/*
+ * arenas_assignment_type_parser -- parses the arenas assignment enum
+ */
+static int
+arenas_assignment_type_parser(const void *arg, void *dest, size_t dest_size)
+{
+	const char *vstr = arg;
+	enum pobj_arenas_assignment_type *atype = dest;
+	ASSERTeq(dest_size, sizeof(enum pobj_header_type));
+
+	if (strcmp(vstr, "global") == 0) {
+		*atype = POBJ_ARENAS_ASSIGNMENT_GLOBAL;
+	} else if (strcmp(vstr, "thread") == 0) {
+		*atype = POBJ_ARENAS_ASSIGNMENT_THREAD_KEY;
+	} else {
+		ERR("invalid arena assignment type");
+		errno = EINVAL;
+		return -1;
+	}
+
+	return 0;
+}
+
+static const struct ctl_argument CTL_ARG(arenas_assignment_type) = {
+	.dest_size = sizeof(enum pobj_arenas_assignment_type),
+	.parsers = {
+		CTL_ARG_PARSER(enum pobj_arenas_assignment_type,
+			arenas_assignment_type_parser),
+		CTL_ARG_PARSER_END
+	}
+};
+
+static const struct ctl_node CTL_NODE(heap_global)[] = {
+	CTL_LEAF_RW(arenas_assignment_type),
+
+	CTL_NODE_END
+};
+
+/*
+ * pmalloc_global_ctl_register -- register allocator global ctl entries
+ */
+void
+pmalloc_global_ctl_register(void)
+{
+	ctl_register_module_node(NULL, "heap",
+		(struct ctl_node *)CTL_NODE(heap_global));
+}
