@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2020, Intel Corporation */
 
 /*
  * rpmem.c -- main source file for librpmem
@@ -305,10 +276,10 @@ rpmem_common_fip_init(RPMEMpool *rpp, struct rpmem_req_attr *req,
 		.rkey		= resp->rkey,
 	};
 
-	ret = snprintf(rpp->fip_service, sizeof(rpp->fip_service),
+	ret = util_snprintf(rpp->fip_service, sizeof(rpp->fip_service),
 			"%u", resp->port);
-	if (ret <= 0) {
-		ERR("snprintf: %d", ret);
+	if (ret < 0) {
+		ERR("!snprintf");
 		goto err_port;
 	}
 
@@ -647,7 +618,7 @@ rpmem_flush(RPMEMpool *rpp, size_t offset, size_t length,
 	}
 
 	if (rpp->no_headers == 0 && offset < RPMEM_HDR_SIZE) {
-		ERR("offset (%zu) in pool is less than %d bytes", offset,
+		ERR("offset (%zu) in pool is less than %ld bytes", offset,
 				RPMEM_HDR_SIZE);
 		errno = EINVAL;
 		return -1;
@@ -733,7 +704,7 @@ rpmem_persist(RPMEMpool *rpp, size_t offset, size_t length,
 	}
 
 	if (rpp->no_headers == 0 && offset < RPMEM_HDR_SIZE) {
-		ERR("offset (%zu) in pool is less than %d bytes", offset,
+		ERR("offset (%zu) in pool is less than %ld bytes", offset,
 				RPMEM_HDR_SIZE);
 		errno = EINVAL;
 		return -1;
@@ -779,7 +750,7 @@ rpmem_deep_persist(RPMEMpool *rpp, size_t offset, size_t length, unsigned lane)
 	}
 
 	if (offset < RPMEM_HDR_SIZE) {
-		ERR("offset (%zu) in pool is less than %d bytes", offset,
+		ERR("offset (%zu) in pool is less than %ld bytes", offset,
 				RPMEM_HDR_SIZE);
 		errno = EINVAL;
 		return -1;
@@ -818,7 +789,7 @@ rpmem_read(RPMEMpool *rpp, void *buff, size_t offset,
 	}
 
 	if (rpp->no_headers == 0 && offset < RPMEM_HDR_SIZE)
-		LOG(1, "reading from pool at offset (%zu) less than %d bytes",
+		LOG(1, "reading from pool at offset (%zu) less than %ld bytes",
 				offset, RPMEM_HDR_SIZE);
 
 	int ret = rpmem_fip_read(rpp->fip, buff, length, offset, lane);
@@ -932,12 +903,12 @@ void
 rpmem_inject_fault_at(enum pmem_allocation_type type, int nth,
 						const char *at)
 {
-	return common_inject_fault_at(type, nth, at);
+	return core_inject_fault_at(type, nth, at);
 }
 
 int
 rpmem_fault_injection_enabled(void)
 {
-	return common_fault_injection_enabled();
+	return core_fault_injection_enabled();
 }
 #endif
