@@ -444,10 +444,7 @@ main(int argc, char **argv)
 {
 	START(argc, argv, "pmem2_source");
 
-	util_init();
-	out_init("pmem2_source", "TEST_LOG_LEVEL", "TEST_LOG_FILE", 0, 0);
 	TEST_CASE_PROCESS(argc, argv, test_cases, NTESTS);
-	out_fini();
 
 	DONE(NULL);
 }
