@@ -1,34 +1,5 @@
-/*
- * Copyright 2017-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2017-2019, Intel Corporation */
 
 /*
  * cmpmap -- a tool for comparing files using mmap
@@ -174,7 +145,7 @@ do_cmpmap(void)
 		fprintf(stderr, "opening %s failed, errno %d\n", File1, errno);
 		return -1;
 	}
-	ssize_t size_tmp = util_file_get_size(File1);
+	ssize_t size_tmp = util_fd_get_size(fd1);
 	if (size_tmp < 0) {
 		fprintf(stderr, "getting size of %s failed, errno %d\n", File1,
 				errno);
@@ -199,7 +170,7 @@ do_cmpmap(void)
 			ret = -1;
 			goto out_close1;
 		}
-		size_tmp = util_file_get_size(File2);
+		size_tmp = util_fd_get_size(fd2);
 		if (size_tmp < 0) {
 			fprintf(stderr, "getting size of %s failed, errno %d\n",
 					File2, errno);
