@@ -1,7 +1,60 @@
 # SPDX-License-Identifier: BSD-3-Clause
 # Copyright 2019-2020, Intel Corporation
 
-"""Base tests class and its functionalities"""
+"""Base tests class and its functionalities.
+
+_TestCase metaclass implemented in this module is
+used to register test case classes.
+
+Classes are registered and used as actual test cases only if they fulfill
+the following requirements:
+    - inherit (directly or indirectly) from BaseTest class
+    - reside in TESTS.py file under pmdk/src/test/ directory
+    - are named by TEST[int] (e.g. TEST0), where integer suffix is a
+      test number (used for selecting test sequences).
+
+BaseTest._execute() method requires special attention as a
+general single test execution workflow.
+
+While BaseTest class is the required test case base class, it consist only of
+the minimal implementation to serve as the test framework handle.
+In practice, it is the Test class (inheriting from BaseTest) that is
+most commonly used as a test case direct base class. The Test class
+implements operations typically used by most of the tests.
+
+Test class needs to implement an abstract run(ctx) method, which stands
+for a test body. setup(ctx) and clean(ctx) methods, which are a part
+of test execution workflow are optional. Mind that the Test class already
+provides some implementation of the setup() and clean() - it is
+crucial to call them while implementing own setup() and clean() methods.
+
+Tests for PMDK C code frequently call the Context exec() method
+(passed as 'ctx' argument to run()), which is a utility for
+setting up, running and handling the output of C test binaries.
+
+Example TESTS.py file with a single test case may look like this:
+
+$ cat pmdk/src/test/test_group/TESTS.py
+
+!#../env.py
+
+import testframework as t
+
+
+class TEST0(t.Test):
+    def run(self, ctx):
+        ctx.exec('test_binary')
+
+    def setup(self, ctx):
+        # call Test setup
+        super().setup(ctx)
+        # TEST0 setup implementation goes here
+
+    def clean(self, ctx):
+        super().clean(ctx)
+        # TEST0 clean implementation goes here
+
+"""
 
 import builtins
 import subprocess as sp
@@ -12,10 +65,17 @@ from datetime import datetime
 from os import path
 
 from configurator import Configurator
+from consts import LIBS_LIST, ROOTDIR
 import futils
 import test_types
+import shutil
 
 
+#
+# imported test cases are globally available as a 'builtins'
+# module 'testcases' variable, which is initialized at first basetest
+# module import as an empty list
+#
 if not hasattr(builtins, 'testcases'):
     builtins.testcases = []
 
@@ -35,7 +95,15 @@ def _test_string_repr(cls):
 
 
 class _TestCase(type):
-    """Metaclass for BaseTest that is used for registering imported tests"""
+    """Metaclass for BaseTest that is used for registering imported tests.
+
+    Attributes:
+        cwd (str): path to the directory of the TESTS.py file containing the
+            class
+        group (str): name of the directory of the TESTS.py file
+        testnum (int): test number
+        tc_dirname (str): name of the directory created for the test in testdir
+    """
 
     def __init__(cls, name, bases, dct):
         type.__init__(cls, name, bases, dct)
@@ -68,9 +136,14 @@ class _TestCase(type):
 class BaseTest(metaclass=_TestCase):
     """
     Framework base test class. Every test case needs to (directly or
-    indirectly) inherit from this class. Since this class implements only
-    very abstract test behaviour, it is advised for particular test cases
+    indirectly) inherit from it. Since this class implements only
+    very abstract test behaviour, it is advised for most test cases
     to use Test class inheriting from it.
+
+    Attributes:
+        enabled (bool): True if test is meant to be executed, False otherwise.
+            Defaults to True.
+        ctx (Context): context affiliated with the test
     """
     enabled = True
 
@@ -84,6 +157,9 @@ class BaseTest(metaclass=_TestCase):
         """
         Implementation of basic single contextualized test execution workflow.
         Called by the test runner.
+
+        Args:
+            c (Context): test context
         """
         self.ctx = c
 
@@ -100,7 +176,7 @@ class BaseTest(metaclass=_TestCase):
             self.elapsed = (datetime.now() - start_time).total_seconds()
 
             self.ctx.check()
-            self.check()
+            self.check(c)
 
         except futils.Fail:
             self._on_fail()
@@ -133,7 +209,7 @@ class BaseTest(metaclass=_TestCase):
         raise NotImplementedError('{} does not implement run() method'.format(
             self.__class__))
 
-    def check(self):
+    def check(self, ctx):
         """Run additional test checks - not implemented by BaseTest"""
         pass
 
@@ -149,16 +225,28 @@ class BaseTest(metaclass=_TestCase):
 class Test(BaseTest):
     """
     Generic implementation of BaseTest scaffolding used by particular test
-    case classes as a base.
+    case classes as a base. In practice, most tests need to inherit from
+    this class rather than from Basetest since it implements most commonly
+    used test utilities and actions.
+
+    Args:
+        test_type (_TestType): test type affiliated with test execution
+            length. Defaults to Medium.
+        match (bool): True if match files will be checked for test,
+            False otherwise. Defaults to True.
+        config (Configurator): test execution configuration
+        msg (Message): message class instance with logging level
+        env (dict): environment variables needed for test execution
+
     """
     test_type = test_types.Medium
-    memcheck_check_leaks = True
     match = True
 
     def __init__(self):
         super().__init__()
         self.config = Configurator().config
         self.msg = futils.Message(self.config.unittest_log_level)
+        self.log_files = {}
 
     def _get_utenv(self):
         """Get environment variables values used by C test framework"""
@@ -168,6 +256,21 @@ class Test(BaseTest):
             'UNITTEST_NUM': str(self.testnum)
         }
 
+    def _debug_log_env(self):
+        """
+        Return environment variables that enable logging PMDK debug output
+        into log files
+        """
+
+        envs = {}
+        for libs in LIBS_LIST:
+            envs['{}_LOG_LEVEL'.format(libs.upper())] = '3'
+            log_file = os.path.join(self.cwd,
+                                    '{}_{}.log'.format(libs, self.testnum))
+            envs['{}_LOG_FILE'.format(libs.upper())] = log_file
+            self.log_files[libs] = log_file
+        return envs
+
     def get_log_files(self):
         """
         Returns names of all log files for given test
@@ -191,6 +294,18 @@ class Test(BaseTest):
             with open(file) as f:
                 self.ctx.dump_n_lines(f)
 
+    def _move_log_files(self, ctx):
+        """
+        Move all log files for given tests
+        """
+        path = "logs"
+        sub_dir = str(ctx).replace(':', '')
+        logs_dir = os.path.join(path, sub_dir)
+        os.makedirs(logs_dir, exist_ok=True)
+        log_files = self.get_log_files()
+        for file in log_files:
+            shutil.copy2(file, logs_dir)
+
     def remove_log_files(self):
         """
         Removes log files for given test
@@ -203,6 +318,7 @@ class Test(BaseTest):
         """Test setup"""
         self.env = {}
         self.env.update(self._get_utenv())
+        self.env.update(self._debug_log_env())
         self.ctx.add_env(self.env)
 
         self.remove_log_files()
@@ -210,10 +326,11 @@ class Test(BaseTest):
     def _on_fail(self):
         self._print_log_files()
 
-    def check(self):
+    def check(self, ctx):
         """Run additional test checks"""
         if self.match:
             self._run_match()
+        self._move_log_files(ctx)
 
     def _run_match(self):
         """Match log files"""
@@ -230,7 +347,7 @@ class Test(BaseTest):
 
         match_files = filter(is_matchfile, cwd_listdir)
         prefix = 'perl ' if sys.platform == 'win32' else ''
-        match_cmd = prefix + path.join(futils.ROOTDIR, 'match')
+        match_cmd = prefix + path.join(ROOTDIR, 'match')
 
         for mf in match_files:
             cmd = '{} {}'.format(match_cmd, mf)
