@@ -1,34 +1,5 @@
-/*
- * Copyright 2018-2020, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2018-2020, Intel Corporation */
 
 /*
  * daxio.c -- simple app for reading and writing data from/to
@@ -54,7 +25,8 @@
 #include <libpmem.h>
 
 #include "util.h"
-#include "os_dimm.h"
+#include "os.h"
+#include "badblocks.h"
 
 #define ALIGN_UP(size, align) (((size) + (align) - 1) & ~((align) - 1))
 #define ALIGN_DOWN(size, align) ((size) & ~((align) - 1))
@@ -352,14 +324,14 @@ setup_device(struct ndctl_ctx *ndctl_ctx, struct daxio_device *dev, int is_dst,
 	}
 
 	/* try to open file/device (if exists) */
-	dev->fd = open(dev->path, flags, S_IRUSR|S_IWUSR);
+	dev->fd = os_open(dev->path, flags, S_IRUSR|S_IWUSR);
 	if (dev->fd == -1) {
 		ret = errno;
 		if (ret == ENOENT && is_dst) {
 			/* file does not exist - create it */
 			flags = O_CREAT|O_WRONLY|O_TRUNC;
 			dev->size = SIZE_MAX;
-			dev->fd = open(dev->path, flags, S_IRUSR|S_IWUSR);
+			dev->fd = os_open(dev->path, flags, S_IRUSR|S_IWUSR);
 			if (dev->fd == -1) {
 				FAIL("open");
 				return -1;
@@ -404,7 +376,7 @@ setup_device(struct ndctl_ctx *ndctl_ctx, struct daxio_device *dev, int is_dst,
 
 	if (is_dst && clear_bad_blocks) {
 		/* XXX - clear only badblocks in range bound by offset/len */
-		if (os_dimm_devdax_clear_badblocks_all(dev->path)) {
+		if (badblocks_clear_all(dev->path)) {
 			ERR("failed to clear bad blocks on \"%s\"\n"
 			    "       Probably you have not enough permissions to do that.\n"
 			    "       You can choose one of three options now:\n"
